@@ -10,8 +10,7 @@ selective axes of a 3D plot.
 import numpy as np
 import matplotlib.pyplot as plt
 
-fig = plt.figure()
-ax = fig.gca(projection='3d')
+ax = plt.figure().add_subplot(projection='3d')
 
 # Plot a sin curve using the x and y axes.
 x = np.linspace(0, 1, 100)
