@@ -13,13 +13,12 @@ import matplotlib.pyplot as plt
 import numpy as np
 
 # Load and format data
-with cbook.get_sample_data('jacksboro_fault_dem.npz') as file, \
-     np.load(file) as dem:
-    z = dem['elevation']
-    nrows, ncols = z.shape
-    x = np.linspace(dem['xmin'], dem['xmax'], ncols)
-    y = np.linspace(dem['ymin'], dem['ymax'], nrows)
-    x, y = np.meshgrid(x, y)
+dem = cbook.get_sample_data('jacksboro_fault_dem.npz', np_load=True)
+z = dem['elevation']
+nrows, ncols = z.shape
+x = np.linspace(dem['xmin'], dem['xmax'], ncols)
+y = np.linspace(dem['ymin'], dem['ymax'], nrows)
+x, y = np.meshgrid(x, y)
 
 region = np.s_[5:50, 5:50]
 x, y, z = x[region], y[region], z[region]
