@@ -1,6 +1,5 @@
 import functools
 import itertools
-import platform
 
 import pytest
 
@@ -547,7 +546,7 @@ def test_text3d_modification(fig_ref, fig_test):
         ax_ref.text(x, y, z, f'({x}, {y}, {z}), dir={zdir}', zdir=zdir)
 
 
-@mpl3d_image_comparison(['trisurf3d.png'], tol=0.03)
+@mpl3d_image_comparison(['trisurf3d.png'], tol=0.061)
 def test_trisurf3d():
     n_angles = 36
     n_radii = 8
@@ -704,6 +703,16 @@ def test_patch_collection_modification(fig_test, fig_ref):
     ax_ref.add_collection3d(c)
 
 
+def test_poly3dcollection_verts_validation():
+    poly = [[0, 0, 1], [0, 1, 1], [0, 1, 0], [0, 0, 0]]
+    with pytest.raises(ValueError, match=r'list of \(N, 3\) array-like'):
+        art3d.Poly3DCollection(poly)  # should be Poly3DCollection([poly])
+
+    poly = np.array(poly, dtype=float)
+    with pytest.raises(ValueError, match=r'list of \(N, 3\) array-like'):
+        art3d.Poly3DCollection(poly)  # should be Poly3DCollection([poly])
+
+
 @mpl3d_image_comparison(['poly3dcollection_closed.png'])
 def test_poly3dcollection_closed():
     fig = plt.figure()
@@ -992,6 +1001,16 @@ def test_lines_dists():
     ax.set_ylim(0, 300)
 
 
+def test_lines_dists_nowarning():
+    # Smoke test to see that no RuntimeWarning is emitted when two first
+    # arguments are the same, see GH#22624
+    p0 = (10, 30)
+    p1 = (20, 150)
+    proj3d._line2d_seg_dist(p0, p0, p1)
+    p0 = np.array(p0)
+    proj3d._line2d_seg_dist(p0, p0, p1)
+
+
 def test_autoscale():
     fig, ax = plt.subplots(subplot_kw={"projection": "3d"})
     ax.margins(x=0, y=.1, z=.2)
@@ -1357,7 +1376,7 @@ def test_errorbar3d():
 
 
 @image_comparison(['stem3d.png'], style='mpl20',
-                  tol=0.0 if platform.machine() == 'x86_64' else 0.003)
+                  tol=0.003)
 def test_stem3d():
     fig, axs = plt.subplots(2, 3, figsize=(8, 6),
                             constrained_layout=True,
@@ -1701,3 +1720,63 @@ def test_view_init_vertical_axis(
         tickdir_expected = tickdirs_expected[i]
         tickdir_actual = axis._get_tickdir()
         np.testing.assert_array_equal(tickdir_expected, tickdir_actual)
+
+
+def test_do_3d_projection_renderer_deprecation_warn_on_argument():
+    """
+    Test that an external artist with an old-style calling convention raises
+    a suitable deprecation warning.
+    """
+    class DummyPatch(art3d.Patch3D):
+        def do_3d_projection(self, renderer):
+            return 0
+
+        def draw(self, renderer):
+            pass
+
+    fig = plt.figure()
+    ax = fig.add_subplot(111, projection='3d')
+    artist = DummyPatch()
+    ax.add_artist(artist)
+
+    match = r"The 'renderer' parameter of do_3d_projection\(\) was deprecated"
+    with pytest.warns(MatplotlibDeprecationWarning, match=match):
+        fig.canvas.draw()
+
+
+def test_do_3d_projection_renderer_deprecation_nowarn_on_optional_argument():
+    """
+    Test that an external artist with a calling convention compatible with
+    both v3.3 and v3.4 does not raise a deprecation warning.
+    """
+    class DummyPatch(art3d.Patch3D):
+        def do_3d_projection(self, renderer=None):
+            return 0
+
+        def draw(self, renderer):
+            pass
+
+    fig = plt.figure()
+    ax = fig.add_subplot(111, projection='3d')
+    artist = DummyPatch()
+    ax.add_artist(artist)
+    fig.canvas.draw()
+
+
+def test_do_3d_projection_renderer_deprecation_nowarn_on_no_argument():
+    """
+    Test that an external artist with a calling convention compatible with
+    only v3.4 does not raise a deprecation warning.
+    """
+    class DummyPatch(art3d.Patch3D):
+        def do_3d_projection(self):
+            return 0
+
+        def draw(self, renderer):
+            pass
+
+    fig = plt.figure()
+    ax = fig.add_subplot(111, projection='3d')
+    artist = DummyPatch()
+    ax.add_artist(artist)
+    fig.canvas.draw()
